==> estateplat-common-1.1.0-20160823.064310-165-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzFdcq2.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 房地产权（独幢、层、套、间房屋）信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:19
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_fdcq2")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzFdcq2 implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //房地坐落
    @XmlElement(name = "fdzl")
    private String fdzl;
    //土地使用权人
    @XmlElement(name = "tdsyqr")
    private String tdsyqr;
    //独用土地面积
    @XmlElement(name = "dytdmj")
    private Double dytdmj;
    //分摊土地面积
    @XmlElement(name = "fttdmj")
    private Double fttdmj;
    //土地使用起始时间
    @XmlElement(name = "tdsyqssj")
    private Date tdsyqssj;
    //土地使用结束时间
    @XmlElement(name = "tdsyjssj")
    private Date tdsyjssj;
    //房地产交易价格
    @XmlElement(name = "fdcjyjg")
    private Double fdcjyjg;
    //规划用途
    @XmlElement(name = "ghyt")
    private String ghyt;
    //房屋性质
    @XmlElement(name = "fwxz")
    private String fwxz;
    //房屋结构
    @XmlElement(name = "fwjg")
    private String fwjg;
    //所在层
    @XmlElement(name = "szc")
    private Integer szc;
    //总层数
    @XmlElement(name = "zcs")
    private Integer zcs;
    //建筑面积
    @XmlElement(name = "jzmj")
    private Double jzmj;
    //专有建筑面积
    @XmlElement(name = "zyjzmj")
    private Double zyjzmj;
    //分摊建筑面积
    @XmlElement(name = "ftjzmj")
    private Double ftjzmj;
    //竣工时间
    @XmlElement(name = "jgsj")
    private Date jgsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //所在名义层
    @XmlElement(name = "szmyc")
    private String szmyc;


    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getFdzl() {
        return fdzl;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getZyjzmj() {
        return zyjzmj;
    }

    public void setZyjzmj(Double zyjzmj) {
        this.zyjzmj = zyjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20220613.055517-1039-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzFdcq2.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 房地产权（独幢、层、套、间房屋）信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:19
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_fdcq2")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzFdcq2 implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //房地坐落
    @XmlElement(name = "fdzl")
    private String fdzl;
    //土地使用权人
    @XmlElement(name = "tdsyqr")
    private String tdsyqr;
    //独用土地面积
    @XmlElement(name = "dytdmj")
    private Double dytdmj;
    //分摊土地面积
    @XmlElement(name = "fttdmj")
    private Double fttdmj;
    //土地使用起始时间
    @XmlElement(name = "tdsyqssj")
    private Date tdsyqssj;
    //土地使用结束时间
    @XmlElement(name = "tdsyjssj")
    private Date tdsyjssj;
    //房地产交易价格
    @XmlElement(name = "fdcjyjg")
    private Double fdcjyjg;
    //规划用途
    @XmlElement(name = "ghyt")
    private String ghyt;
    //房屋性质
    @XmlElement(name = "fwxz")
    private String fwxz;
    //房屋结构
    @XmlElement(name = "fwjg")
    private String fwjg;
    //所在层
    @XmlElement(name = "szc")
    private Integer szc;
    //总层数
    @XmlElement(name = "zcs")
    private Integer zcs;
    //建筑面积
    @XmlElement(name = "jzmj")
    private Double jzmj;
    //专有建筑面积
    @XmlElement(name = "zyjzmj")
    private Double zyjzmj;
    //分摊建筑面积
    @XmlElement(name = "ftjzmj")
    private Double ftjzmj;
    //竣工时间
    @XmlElement(name = "jgsj")
    private Date jgsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //所在名义层
    @XmlElement(name = "szmyc")
    private String szmyc;


    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;
    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getFdzl() {
        return fdzl;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getZyjzmj() {
        return zyjzmj;
    }

    public void setZyjzmj(Double zyjzmj) {
        this.zyjzmj = zyjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSzmyc() {
        return szmyc;
    }

    public void setSzmyc(String szmyc) {
        this.szmyc = szmyc;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
